// SPDX-License-Identifier: LGPL-2.1-or-later
//
// SPDX-FileCopyrightText: 2012 Bernhard Beschow <bbeschow@cs.tu-berlin.de>
//

#include "DialogConfigurationInterface.h"

namespace Marble
{

DialogConfigurationInterface::~DialogConfigurationInterface() = default;
}
